@@ -1,5 +1,5 @@
 package Audio::Nama::Globals;
-use Modern::Perl;
+use Modern::Perl '2020';
 
 # set aliases for common indices
 *bn = \%Audio::Nama::Bus::by_name;
