@@ -6,7 +6,7 @@
 #
 
 package Audio::Nama;
-use Modern::Perl; use Carp;
+use Modern::Perl '2020'; use Carp;
 use Socket qw(getnameinfo NI_NUMERICHOST) ;
 
 sub is_test_script { $config->{opts}->{J} }
@@ -245,7 +245,7 @@ sub definitions {
 	{ package Audio::Nama::Config;
 	use Carp;
 	use Audio::Nama::Globals qw(:singletons);
-	use Modern::Perl;
+	use Modern::Perl '2020';
 	our @ISA = 'Audio::Nama::Object'; #  for ->dump and ->as_hash methods
 
 	sub serialize_formats { split " ", $_[0]->{serialize_formats} }
