@@ -3,7 +3,7 @@
 
 package Audio::Nama;
 use File::Copy;
-use Modern::Perl; no warnings 'uninitialized';
+use Modern::Perl '2020'; no warnings 'uninitialized';
 
 sub save_state {
 	logsub((caller(0))[3]);
