@@ -19,13 +19,12 @@ use Audio::Nama::Log qw(logpkg logsub);
 use Audio::Nama::Effect  qw(fxn);
 use List::MoreUtils qw(first_index);
 use Try::Tiny;
-use Modern::Perl;
+use Modern::Perl '2020';
 use Carp qw(carp cluck croak);
 use File::Copy qw(copy);
 use File::Slurp;
 use Memoize qw(memoize unmemoize);
 no warnings qw(uninitialized redefine);
-our $VERSION = 1.0;
 
 use Audio::Nama::Util qw(freq input_node dest_type dest_string join_path);
 use Audio::Nama::Assign qw(json_out);
@@ -280,7 +279,7 @@ sub fades { grep { $_->{track} eq $_[0]->name } values %Audio::Nama::Fade::by_in
 {
 package Audio::Nama::SimpleTrack; # used for Main track
 use Audio::Nama::Globals qw(:all);
-use Modern::Perl; use Carp; use Audio::Nama::Log qw(logpkg);
+use Modern::Perl '2020'; use Carp; use Audio::Nama::Log qw(logpkg);
 use SUPER;
 no warnings qw(uninitialized redefine);
 our @ISA = 'Audio::Nama::Track';
@@ -299,7 +298,7 @@ sub activate_bus {}
 {
 package Audio::Nama::MasteringTrack; # used for mastering chains 
 use Audio::Nama::Globals qw(:all);
-use Modern::Perl; use Audio::Nama::Log qw(logpkg);
+use Modern::Perl '2020'; use Audio::Nama::Log qw(logpkg);
 no warnings qw(uninitialized redefine);
 our @ISA = 'Audio::Nama::SimpleTrack';
 
@@ -316,7 +315,7 @@ sub version {0}
 package Audio::Nama::EarTrack; # for submix helper tracks
 use Audio::Nama::Globals qw(:all);
 use Audio::Nama::Util qw(dest_string);
-use Modern::Perl; use Audio::Nama::Log qw(logpkg);
+use Modern::Perl '2020'; use Audio::Nama::Log qw(logpkg);
 use SUPER;
 no warnings qw(uninitialized redefine);
 our @ISA = 'Audio::Nama::SlaveTrack';
@@ -332,7 +331,7 @@ sub width { $_[0]->{width} }
 {
 package Audio::Nama::SlaveTrack;
 use Audio::Nama::Globals qw(:all);
-use Modern::Perl; use Audio::Nama::Log qw(logpkg);
+use Modern::Perl '2020'; use Audio::Nama::Log qw(logpkg);
 no warnings qw(uninitialized redefine);
 our @ISA = 'Audio::Nama::Track';
 sub width { $tn{$_[0]->target}->width }
@@ -350,7 +349,7 @@ sub dir { $tn{$_[0]->target}->dir }
 {
 package Audio::Nama::BoostTrack; 
 use Audio::Nama::Globals qw(:all);
-use Modern::Perl; use Audio::Nama::Log qw(logpkg);
+use Modern::Perl '2020'; use Audio::Nama::Log qw(logpkg);
 no warnings qw(uninitialized redefine);
 our @ISA = 'Audio::Nama::Track';
 sub rec_status{
@@ -526,14 +525,14 @@ sub new {
 { 
 package Audio::Nama::WetTrack; # for inserts
 use Audio::Nama::Globals qw(:all);
-use Modern::Perl; use Audio::Nama::Log qw(logpkg);
+use Modern::Perl '2020'; use Audio::Nama::Log qw(logpkg);
 our @ISA = 'Audio::Nama::SlaveTrack';
 }
 
 {
 package Audio::Nama::MidiTrack; 
 use Audio::Nama::Globals qw(:all);
-use Modern::Perl;
+use Modern::Perl '2020';
 use SUPER;
 use Audio::Nama::Log qw(logpkg);
 our @ISA = qw(Audio::Nama::Track);
